@@ -21,10 +21,10 @@ class FitterInterface:
     def __init__(self):
         pass
 
-    def init_fitter(self, fit_global_parameters=None):
+    def initialize(self, fit_global_parameters=None):
         raise NotImplementedError("Abstract")
 
-    def do_fit(self, fit_global_parameters=None, current_iteration=0, compute_pattern=True):
+    def do_fit(self, fit_global_parameters=None, current_iteration=0, compute_pattern=True, compute_errors=True):
         raise NotImplementedError("Abstract")
 
 
