@@ -108,259 +108,9 @@ class OWChebyshevBackground(OWGenericWidget):
     inputs = [("Fit Global Parameters", FitGlobalParameters, 'set_data')]
     outputs = [("Fit Global Parameters", FitGlobalParameters)]
 
-    # TO PRESERVE RETRO-COMPATIBILITY
-    def fix_input(self, emergency=False):
-        if not isinstance(self.c0               , list): self.c0                = [self.c0               ]
-        if not isinstance(self.c1               , list): self.c1                = [self.c1               ]
-        if not isinstance(self.c2               , list): self.c2                = [self.c2               ]
-        if not isinstance(self.c3               , list): self.c3                = [self.c3               ]
-        if not isinstance(self.c4               , list): self.c4                = [self.c4               ]
-        if not isinstance(self.c5               , list): self.c5                = [self.c5               ]
-        if not isinstance(self.c6               , list): self.c6                = [self.c6               ]
-        if not isinstance(self.c7               , list): self.c7                = [self.c7               ]
-        if not isinstance(self.c8               , list): self.c8                = [self.c8               ]
-        if not isinstance(self.c9               , list): self.c9                = [self.c9               ]
-        if not isinstance(self.c0_fixed         , list): self.c0_fixed          = [self.c0_fixed         ]
-        if not isinstance(self.c1_fixed         , list): self.c1_fixed          = [self.c1_fixed         ]
-        if not isinstance(self.c2_fixed         , list): self.c2_fixed          = [self.c2_fixed         ]
-        if not isinstance(self.c3_fixed         , list): self.c3_fixed          = [self.c3_fixed         ]
-        if not isinstance(self.c4_fixed         , list): self.c4_fixed          = [self.c4_fixed         ]
-        if not isinstance(self.c5_fixed         , list): self.c5_fixed          = [self.c5_fixed         ]
-        if not isinstance(self.c6_fixed         , list): self.c6_fixed          = [self.c6_fixed         ]
-        if not isinstance(self.c7_fixed         , list): self.c7_fixed          = [self.c7_fixed         ]
-        if not isinstance(self.c8_fixed         , list): self.c8_fixed          = [self.c8_fixed         ]
-        if not isinstance(self.c9_fixed         , list): self.c9_fixed          = [self.c9_fixed         ]
-        if not isinstance(self.c0_has_min       , list): self.c0_has_min        = [self.c0_has_min       ]
-        if not isinstance(self.c1_has_min       , list): self.c1_has_min        = [self.c1_has_min       ]
-        if not isinstance(self.c2_has_min       , list): self.c2_has_min        = [self.c2_has_min       ]
-        if not isinstance(self.c3_has_min       , list): self.c3_has_min        = [self.c3_has_min       ]
-        if not isinstance(self.c4_has_min       , list): self.c4_has_min        = [self.c4_has_min       ]
-        if not isinstance(self.c5_has_min       , list): self.c5_has_min        = [self.c5_has_min       ]
-        if not isinstance(self.c6_has_min       , list): self.c6_has_min        = [self.c6_has_min       ]
-        if not isinstance(self.c7_has_min       , list): self.c7_has_min        = [self.c7_has_min       ]
-        if not isinstance(self.c8_has_min       , list): self.c8_has_min        = [self.c8_has_min       ]
-        if not isinstance(self.c9_has_min       , list): self.c9_has_min        = [self.c9_has_min       ]
-        if not isinstance(self.c0_min           , list): self.c0_min            = [self.c0_min           ]
-        if not isinstance(self.c1_min           , list): self.c1_min            = [self.c1_min           ]
-        if not isinstance(self.c2_min           , list): self.c2_min            = [self.c2_min           ]
-        if not isinstance(self.c3_min           , list): self.c3_min            = [self.c3_min           ]
-        if not isinstance(self.c4_min           , list): self.c4_min            = [self.c4_min           ]
-        if not isinstance(self.c5_min           , list): self.c5_min            = [self.c5_min           ]
-        if not isinstance(self.c6_min           , list): self.c6_min            = [self.c6_min           ]
-        if not isinstance(self.c7_min           , list): self.c7_min            = [self.c7_min           ]
-        if not isinstance(self.c8_min           , list): self.c8_min            = [self.c8_min           ]
-        if not isinstance(self.c9_min           , list): self.c9_min            = [self.c9_min           ]
-        if not isinstance(self.c0_has_max       , list): self.c0_has_max        = [self.c0_has_max       ]
-        if not isinstance(self.c1_has_max       , list): self.c1_has_max        = [self.c1_has_max       ]
-        if not isinstance(self.c2_has_max       , list): self.c2_has_max        = [self.c2_has_max       ]
-        if not isinstance(self.c3_has_max       , list): self.c3_has_max        = [self.c3_has_max       ]
-        if not isinstance(self.c4_has_max       , list): self.c4_has_max        = [self.c4_has_max       ]
-        if not isinstance(self.c5_has_max       , list): self.c5_has_max        = [self.c5_has_max       ]
-        if not isinstance(self.c6_has_max       , list): self.c6_has_max        = [self.c6_has_max       ]
-        if not isinstance(self.c7_has_max       , list): self.c7_has_max        = [self.c7_has_max       ]
-        if not isinstance(self.c8_has_max       , list): self.c8_has_max        = [self.c8_has_max       ]
-        if not isinstance(self.c9_has_max       , list): self.c9_has_max        = [self.c9_has_max       ]
-        if not isinstance(self.c0_max           , list): self.c0_max            = [self.c0_max           ]
-        if not isinstance(self.c1_max           , list): self.c1_max            = [self.c1_max           ]
-        if not isinstance(self.c2_max           , list): self.c2_max            = [self.c2_max           ]
-        if not isinstance(self.c3_max           , list): self.c3_max            = [self.c3_max           ]
-        if not isinstance(self.c4_max           , list): self.c4_max            = [self.c4_max           ]
-        if not isinstance(self.c5_max           , list): self.c5_max            = [self.c5_max           ]
-        if not isinstance(self.c6_max           , list): self.c6_max            = [self.c6_max           ]
-        if not isinstance(self.c7_max           , list): self.c7_max            = [self.c7_max           ]
-        if not isinstance(self.c8_max           , list): self.c8_max            = [self.c8_max           ]
-        if not isinstance(self.c9_max           , list): self.c9_max            = [self.c9_max           ]
-        if not isinstance(self.c0_function      , list): self.c0_function       = [self.c0_function      ]
-        if not isinstance(self.c1_function      , list): self.c1_function       = [self.c1_function      ]
-        if not isinstance(self.c2_function      , list): self.c2_function       = [self.c2_function      ]
-        if not isinstance(self.c3_function      , list): self.c3_function       = [self.c3_function      ]
-        if not isinstance(self.c4_function      , list): self.c4_function       = [self.c4_function      ]
-        if not isinstance(self.c5_function      , list): self.c5_function       = [self.c5_function      ]
-        if not isinstance(self.c6_function      , list): self.c6_function       = [self.c6_function      ]
-        if not isinstance(self.c7_function      , list): self.c7_function       = [self.c7_function      ]
-        if not isinstance(self.c8_function      , list): self.c8_function       = [self.c8_function      ]
-        if not isinstance(self.c9_function      , list): self.c9_function       = [self.c9_function      ]
-        if not isinstance(self.c0_function_value, list): self.c0_function_value = [self.c0_function_value]
-        if not isinstance(self.c1_function_value, list): self.c1_function_value = [self.c1_function_value]
-        if not isinstance(self.c2_function_value, list): self.c2_function_value = [self.c2_function_value]
-        if not isinstance(self.c3_function_value, list): self.c3_function_value = [self.c3_function_value]
-        if not isinstance(self.c4_function_value, list): self.c4_function_value = [self.c4_function_value]
-        if not isinstance(self.c5_function_value, list): self.c5_function_value = [self.c5_function_value]
-        if not isinstance(self.c6_function_value, list): self.c6_function_value = [self.c6_function_value]
-        if not isinstance(self.c7_function_value, list): self.c7_function_value = [self.c7_function_value]
-        if not isinstance(self.c8_function_value, list): self.c8_function_value = [self.c8_function_value]
-        if not isinstance(self.c9_function_value, list): self.c9_function_value = [self.c9_function_value]
-
-        if emergency:
-            self.c0                = [0.0]
-            self.c1                = [0.0]
-            self.c2                = [0.0]
-            self.c3                = [0.0]
-            self.c4                = [0.0]
-            self.c5                = [0.0]
-            self.c6                = [0.0]
-            self.c7                = [0.0]
-            self.c8                = [0.0]
-            self.c9                = [0.0]
-            self.c0_fixed          = [0]
-            self.c1_fixed          = [0]
-            self.c2_fixed          = [0]
-            self.c3_fixed          = [0]
-            self.c4_fixed          = [0]
-            self.c5_fixed          = [0]
-            self.c6_fixed          = [1]
-            self.c7_fixed          = [1]
-            self.c8_fixed          = [1]
-            self.c9_fixed          = [1]
-            self.c0_has_min        = [0]
-            self.c1_has_min        = [0]
-            self.c2_has_min        = [0]
-            self.c3_has_min        = [0]
-            self.c4_has_min        = [0]
-            self.c5_has_min        = [0]
-            self.c6_has_min        = [0]
-            self.c7_has_min        = [0]
-            self.c8_has_min        = [0]
-            self.c9_has_min        = [0]
-            self.c0_min            = [0.0]
-            self.c1_min            = [0.0]
-            self.c2_min            = [0.0]
-            self.c3_min            = [0.0]
-            self.c4_min            = [0.0]
-            self.c5_min            = [0.0]
-            self.c6_min            = [0.0]
-            self.c7_min            = [0.0]
-            self.c8_min            = [0.0]
-            self.c9_min            = [0.0]
-            self.c0_has_max        = [0]
-            self.c1_has_max        = [0]
-            self.c2_has_max        = [0]
-            self.c3_has_max        = [0]
-            self.c4_has_max        = [0]
-            self.c5_has_max        = [0]
-            self.c6_has_max        = [0]
-            self.c7_has_max        = [0]
-            self.c8_has_max        = [0]
-            self.c9_has_max        = [0]
-            self.c0_max            = [0.0]
-            self.c1_max            = [0.0]
-            self.c2_max            = [0.0]
-            self.c3_max            = [0.0]
-            self.c4_max            = [0.0]
-            self.c5_max            = [0.0]
-            self.c6_max            = [0.0]
-            self.c7_max            = [0.0]
-            self.c8_max            = [0.0]
-            self.c9_max            = [0.0]
-            self.c0_function       = [0]
-            self.c1_function       = [0]
-            self.c2_function       = [0]
-            self.c3_function       = [0]
-            self.c4_function       = [0]
-            self.c5_function       = [0]
-            self.c6_function       = [0]
-            self.c7_function       = [0]
-            self.c8_function       = [0]
-            self.c9_function       = [0]
-            self.c0_function_value = [""]
-            self.c1_function_value = [""]
-            self.c2_function_value = [""]
-            self.c3_function_value = [""]
-            self.c4_function_value = [""]
-            self.c5_function_value = [""]
-            self.c6_function_value = [""]
-            self.c7_function_value = [""]
-            self.c8_function_value = [""]
-            self.c9_function_value = [""]
-        else:
-            if len(self.c0               ) == 0: self.c0                = [0.0]
-            if len(self.c1               ) == 0: self.c1                = [0.0]
-            if len(self.c2               ) == 0: self.c2                = [0.0]
-            if len(self.c3               ) == 0: self.c3                = [0.0]
-            if len(self.c4               ) == 0: self.c4                = [0.0]
-            if len(self.c5               ) == 0: self.c5                = [0.0]
-            if len(self.c6               ) == 0: self.c6                = [0.0]
-            if len(self.c7               ) == 0: self.c7                = [0.0]
-            if len(self.c8               ) == 0: self.c8                = [0.0]
-            if len(self.c9               ) == 0: self.c9                = [0.0]
-            if len(self.c0_fixed         ) == 0: self.c0_fixed          = [0]
-            if len(self.c1_fixed         ) == 0: self.c1_fixed          = [0]
-            if len(self.c2_fixed         ) == 0: self.c2_fixed          = [0]
-            if len(self.c3_fixed         ) == 0: self.c3_fixed          = [0]
-            if len(self.c4_fixed         ) == 0: self.c4_fixed          = [0]
-            if len(self.c5_fixed         ) == 0: self.c5_fixed          = [0]
-            if len(self.c6_fixed         ) == 0: self.c6_fixed          = [1]
-            if len(self.c7_fixed         ) == 0: self.c7_fixed          = [1]
-            if len(self.c8_fixed         ) == 0: self.c8_fixed          = [1]
-            if len(self.c9_fixed         ) == 0: self.c9_fixed          = [1]
-            if len(self.c0_has_min       ) == 0: self.c0_has_min        = [0]
-            if len(self.c1_has_min       ) == 0: self.c1_has_min        = [0]
-            if len(self.c2_has_min       ) == 0: self.c2_has_min        = [0]
-            if len(self.c3_has_min       ) == 0: self.c3_has_min        = [0]
-            if len(self.c4_has_min       ) == 0: self.c4_has_min        = [0]
-            if len(self.c5_has_min       ) == 0: self.c5_has_min        = [0]
-            if len(self.c6_has_min       ) == 0: self.c6_has_min        = [0]
-            if len(self.c7_has_min       ) == 0: self.c7_has_min        = [0]
-            if len(self.c8_has_min       ) == 0: self.c8_has_min        = [0]
-            if len(self.c9_has_min       ) == 0: self.c9_has_min        = [0]
-            if len(self.c0_min           ) == 0: self.c0_min            = [0.0]
-            if len(self.c1_min           ) == 0: self.c1_min            = [0.0]
-            if len(self.c2_min           ) == 0: self.c2_min            = [0.0]
-            if len(self.c3_min           ) == 0: self.c3_min            = [0.0]
-            if len(self.c4_min           ) == 0: self.c4_min            = [0.0]
-            if len(self.c5_min           ) == 0: self.c5_min            = [0.0]
-            if len(self.c6_min           ) == 0: self.c6_min            = [0.0]
-            if len(self.c7_min           ) == 0: self.c7_min            = [0.0]
-            if len(self.c8_min           ) == 0: self.c8_min            = [0.0]
-            if len(self.c9_min           ) == 0: self.c9_min            = [0.0]
-            if len(self.c0_has_max       ) == 0: self.c0_has_max        = [0]
-            if len(self.c1_has_max       ) == 0: self.c1_has_max        = [0]
-            if len(self.c2_has_max       ) == 0: self.c2_has_max        = [0]
-            if len(self.c3_has_max       ) == 0: self.c3_has_max        = [0]
-            if len(self.c4_has_max       ) == 0: self.c4_has_max        = [0]
-            if len(self.c5_has_max       ) == 0: self.c5_has_max        = [0]
-            if len(self.c6_has_max       ) == 0: self.c6_has_max        = [0]
-            if len(self.c7_has_max       ) == 0: self.c7_has_max        = [0]
-            if len(self.c8_has_max       ) == 0: self.c8_has_max        = [0]
-            if len(self.c9_has_max       ) == 0: self.c9_has_max        = [0]
-            if len(self.c0_max           ) == 0: self.c0_max            = [0.0]
-            if len(self.c1_max           ) == 0: self.c1_max            = [0.0]
-            if len(self.c2_max           ) == 0: self.c2_max            = [0.0]
-            if len(self.c3_max           ) == 0: self.c3_max            = [0.0]
-            if len(self.c4_max           ) == 0: self.c4_max            = [0.0]
-            if len(self.c5_max           ) == 0: self.c5_max            = [0.0]
-            if len(self.c6_max           ) == 0: self.c6_max            = [0.0]
-            if len(self.c7_max           ) == 0: self.c7_max            = [0.0]
-            if len(self.c8_max           ) == 0: self.c8_max            = [0.0]
-            if len(self.c9_max           ) == 0: self.c9_max            = [0.0]
-            if len(self.c0_function      ) == 0: self.c0_function       = [0]
-            if len(self.c1_function      ) == 0: self.c1_function       = [0]
-            if len(self.c2_function      ) == 0: self.c2_function       = [0]
-            if len(self.c3_function      ) == 0: self.c3_function       = [0]
-            if len(self.c4_function      ) == 0: self.c4_function       = [0]
-            if len(self.c5_function      ) == 0: self.c5_function       = [0]
-            if len(self.c6_function      ) == 0: self.c6_function       = [0]
-            if len(self.c7_function      ) == 0: self.c7_function       = [0]
-            if len(self.c8_function      ) == 0: self.c8_function       = [0]
-            if len(self.c9_function      ) == 0: self.c9_function       = [0]
-            if len(self.c0_function_value) == 0: self.c0_function_value = [""]
-            if len(self.c1_function_value) == 0: self.c1_function_value = [""]
-            if len(self.c2_function_value) == 0: self.c2_function_value = [""]
-            if len(self.c3_function_value) == 0: self.c3_function_value = [""]
-            if len(self.c4_function_value) == 0: self.c4_function_value = [""]
-            if len(self.c5_function_value) == 0: self.c5_function_value = [""]
-            if len(self.c6_function_value) == 0: self.c6_function_value = [""]
-            if len(self.c7_function_value) == 0: self.c7_function_value = [""]
-            if len(self.c8_function_value) == 0: self.c8_function_value = [""]
-            if len(self.c9_function_value) == 0: self.c9_function_value = [""]
-
-
-
     def __init__(self):
         super().__init__(show_automatic_box=True)
 
-        if self.IS_FIX: self.fix_input()
-
         main_box = gui.widgetBox(self.controlArea,
                                  "Chebyshev Parameters", orientation="vertical",
                                  width=self.CONTROL_AREA_WIDTH - 10, height=600)
